#include "modest_config.h"

// myurl
#include "third_party/modest/source/myurl/myosi.c"
#include "third_party/modest/source/myurl/punycode.c"
#include "third_party/modest/source/myurl/path.c"
#include "third_party/modest/source/myurl/scheme.c"
#include "third_party/modest/source/myurl/url.c"
#include "third_party/modest/source/myurl/utils.c"
#include "third_party/modest/source/myurl/serialization.c"
#include "third_party/modest/source/myurl/parser_end.c"
#include "third_party/modest/source/myurl/host.c"
#include "third_party/modest/source/myurl/parser.c"
