package HTML5::DOM::Encoding;
use strict;
use warnings;

# <MyENCODING_const>
use constant	DEFAULT					=> 0x0;
use constant	AUTO					=> 0x1;
use constant	NOT_DETERMINED			=> 0x2;
use constant	UTF_8					=> 0x0;
use constant	UTF_16LE				=> 0x4;
use constant	UTF_16BE				=> 0x5;
use constant	X_USER_DEFINED			=> 0x6;
use constant	BIG5					=> 0x7;
use constant	EUC_JP					=> 0x8;
use constant	EUC_KR					=> 0x9;
use constant	GB18030					=> 0xa;
use constant	GBK						=> 0xb;
use constant	IBM866					=> 0xc;
use constant	ISO_2022_JP				=> 0xd;
use constant	ISO_8859_10				=> 0xe;
use constant	ISO_8859_13				=> 0xf;
use constant	ISO_8859_14				=> 0x10;
use constant	ISO_8859_15				=> 0x11;
use constant	ISO_8859_16				=> 0x12;
use constant	ISO_8859_2				=> 0x13;
use constant	ISO_8859_3				=> 0x14;
use constant	ISO_8859_4				=> 0x15;
use constant	ISO_8859_5				=> 0x16;
use constant	ISO_8859_6				=> 0x17;
use constant	ISO_8859_7				=> 0x18;
use constant	ISO_8859_8				=> 0x19;
use constant	ISO_8859_8_I			=> 0x1a;
use constant	KOI8_R					=> 0x1b;
use constant	KOI8_U					=> 0x1c;
use constant	MACINTOSH				=> 0x1d;
use constant	SHIFT_JIS				=> 0x1e;
use constant	WINDOWS_1250			=> 0x1f;
use constant	WINDOWS_1251			=> 0x20;
use constant	WINDOWS_1252			=> 0x21;
use constant	WINDOWS_1253			=> 0x22;
use constant	WINDOWS_1254			=> 0x23;
use constant	WINDOWS_1255			=> 0x24;
use constant	WINDOWS_1256			=> 0x25;
use constant	WINDOWS_1257			=> 0x26;
use constant	WINDOWS_1258			=> 0x27;
use constant	WINDOWS_874				=> 0x28;
use constant	X_MAC_CYRILLIC			=> 0x29;
use constant	LAST_ENTRY				=> 0x2a;
use constant	STATUS_OK				=> 0x0;
use constant	STATUS_ERROR			=> 0x1;
use constant	STATUS_CONTINUE			=> 0x2;
use constant	STATUS_DONE				=> 0x4;
# </MyENCODING_const>

1;
